@@ -8,8 +8,9 @@ print.pencopula <- function(x,...) {
   cat("\nNumber of marginal observations: ",get("n",x),"\n",sep="")
   cat("\nNumber of covariates: ",p,"\n",sep="")
   cat("\nNumber of estimated coefficients: ",ddb,"\n",sep="")
-  cat("\nHierarchy level of marginal hierarchical B-Spline d: ",d,"\n",sep="")
-  cat("\nMaximum hierarchy level of hierarchical B-Spline basis D: ",D,"\n",sep="")
+  if(get("base",x)=="B-spline") cat("\nHierarchy level of marginal hierarchical B-Spline d: ",d,"\n",sep="")
+  if(get("base",x)=="Bernstein") cat("\nNumber of marginal Bernstein Polynomials: ",ddb,"\n",sep="")
+  if(base=="B-spline") cat("\nMaximum hierarchy level of hierarchical B-Spline basis D: ",D,"\n",sep="")
   if(base=="Bernstein") cat("\nUsed basis: ",base,"\n",sep="")
   if(base=="B-spline") cat("\nUsed basis: ",base," of degree ",q,"\n",sep="")
   names <- c()
